﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using JobTracking.Models;

namespace JobTracking.Controllers
{
    [Authorize]
    public class JobController : Controller
    {
        private JobTrackerEntities db = new JobTrackerEntities();

        //
        // GET: /Job/

        public ViewResult Index()
        {

            if (User.IsInRole("Administrator") || User.IsInRole("Technician"))
            {
                var jobs = db.Jobs.Include("aspnet_Users").Include("aspnet_Users1").Include("aspnet_Users2").Include("Client");
                var list=jobs.ToList();
                return View(list);
            }
            else
            {
                var jobs = db.Jobs.Include("aspnet_Users").Include("aspnet_Users1").Include("aspnet_Users2").Include("Client").Where(s => s.CreatedByUserID == CurrentUser.UserID);
              // List<Job> list = new List<Job>();
                var list = jobs.ToList();
                return View(list);
            }
 
          
        }
        /*
        public ActionResult Browse(string user)
        {

            return View(genreModel);
        }
         * */
        //
        // GET: /Job/Details/5

        public ViewResult Details(int id)
        {
            Job job = db.Jobs.Single(j => j.JobID == id);
            return View(job);
        }

        //
        // GET: /Job/Create

        public ActionResult Create()
        {
            ViewBag.AssignedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName");
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName");
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName");
            ViewBag.ClientID = new SelectList(db.Clients, "ClientID", "CompanyName");
            return View();
        } 

        //
        // POST: /Job/Create

        [HttpPost]
        public ActionResult Create(Job job)
        {
            if (ModelState.IsValid)
            {
                job.CreationDateDime = DateTime.Now;
                job.CompletedDateTime = new DateTime(9999,12,1);
                job.AssignedDateTime = new DateTime(9999, 12, 1);
                job.CreatedByUserID = CurrentUser.UserID;
                db.Jobs.AddObject(job);
                db.SaveChanges();
                return RedirectToAction("Index");  
            }

            ViewBag.AssignedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.AssignedByUserID);
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.CreatedByUserID);
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.UserID);
            ViewBag.ClientID = new SelectList(db.Clients, "ClientID", "CompanyName", job.ClientID);
            return View(job);
        }
        
        //
        // GET: /Job/Edit/5
        [Authorize(Roles = "Administrator")]
        public ActionResult Edit(int id)
        {
            Job job = db.Jobs.Single(j => j.JobID == id);
            ViewBag.AssignedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.AssignedByUserID);
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.CreatedByUserID);
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.UserID);
            ViewBag.ClientID = new SelectList(db.Clients, "ClientID", "CompanyName", job.ClientID);
            return View(job);
        }

        //
        // POST: /Job/Edit/5

        [HttpPost]
        public ActionResult Edit(Job job)
        {
            if (ModelState.IsValid)
            {
                db.Jobs.Attach(job);
                db.ObjectStateManager.ChangeObjectState(job, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.AssignedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.AssignedByUserID);
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.CreatedByUserID);
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.UserID);
            ViewBag.ClientID = new SelectList(db.Clients, "ClientID", "CompanyName", job.ClientID);
            return View(job);
        }

        //
        // GET: /Job/Delete/5
        [Authorize(Roles = "Administrator")]
        public ActionResult Delete(int id)
        {
            Job job = db.Jobs.Include("aspnet_Users").Include("aspnet_Users1").Include("aspnet_Users2").Include("Client").Single(j => j.JobID == id);
           
            
            return View(job);
        }

        //
        // POST: /Job/Delete/5
     
        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {            
            Job job = db.Jobs.Single(j => j.JobID == id);
            db.Jobs.DeleteObject(job);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        //
        // GET: /Job/Complete/5
        [Authorize(Roles = "Administrator,Technician")]
        public ActionResult Complete(int id)
        {
            Job job = db.Jobs.Include("aspnet_Users").Include("aspnet_Users1").Include("aspnet_Users2").Include("Client").Single(j => j.JobID == id);

            return View(job);
        }

        //
        // POST: /Job/Complete/5

        [HttpPost, ActionName("Complete")]
        public ActionResult CompleteConfirmed(int id)
        {

                Job job = db.Jobs.Single(j => j.JobID == id);
                job.CompletedDateTime = DateTime.Now;
                job.UserID = CurrentUser.UserID;
                db.Jobs.Attach(job);
                db.ObjectStateManager.ChangeObjectState(job, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
       
        }
        //
        // GET: /Job/Assign/5
        [Authorize(Roles = "Administrator,Technician")]
        public ActionResult Assign(int id)
        {
            Job job = db.Jobs.Single(j => j.JobID == id);
            ViewBag.AssignedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.AssignedByUserID);
            return View(job);
        }
        public ActionResult Notes(int id)
        {
            Job job = db.Jobs.Single(j => j.JobID == id);
            CurrentJob.JobID = id;
            CurrentJob.ClientID = job.ClientID;

            return RedirectToAction("Index","Note");
        }
        public ActionResult Ticket(int id)
        {
            Job job = db.Jobs.Single(j => j.JobID == id);
            CurrentJob.JobID = id;
            CurrentJob.ClientID = job.ClientID;

            return RedirectToAction("Index", "Ticket");
        }
        public ActionResult JobWorksLog(int id)
        {
            Job job = db.Jobs.Single(j => j.JobID == id);
            CurrentJob.JobID = id;
            CurrentJob.ClientID = job.ClientID;

            return RedirectToAction("Index", "JobWorksLog");
        }
        //
        // POST: /Job/Assign/5

        [HttpPost, ActionName("Assign")]
        public ActionResult Assign(Job job)
        {

           
            if (ModelState.IsValid)
            {
                job.AssignedDateTime = DateTime.Now;
                db.Jobs.Attach(job);
                db.ObjectStateManager.ChangeObjectState(job, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.AssignedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", job.AssignedByUserID);
           
            return View(job);
       

        }
        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}