﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using JobTracking.Models;

namespace JobTracking.Controllers
{ 
    public class NoteController : Controller
    {
        private JobTrackerEntities db = new JobTrackerEntities();

        //
        // GET: /Note/

        public ViewResult Index(string noteCategory, string body,int? temp)
        {
            //var notes = db.Notes.Include("aspnet_Users").Include("NoteType").Include("aspnet_Users_1").Include("Job");
            bool roleStatus=User.IsInRole("Administrator") || User.IsInRole("Technician");
            var notes = db.Notes.Include("aspnet_Users").Include("NoteType").
                  Where(s => s.JobID == CurrentJob.JobID && (!s.IsPrivate || roleStatus));

            if (!string.IsNullOrEmpty(noteCategory))
                notes = notes.Where(a => a.NoteType.Description.Contains(noteCategory)); ;

            if (!string.IsNullOrEmpty(body))
                notes = notes.Where(a => a.Body.Contains(body));
            return View(notes.ToList());
        }
        /*
        [HttpPost]
        public ActionResult Index(string noteCategory, string body)
        {
            bool roleStatus = User.IsInRole("Administrator") || User.IsInRole("Technician");
            var notes = db.Notes.Include("aspnet_Users").Include("NoteType").
                  Where(s => s.JobID == CurrentJob.JobID && (!s.IsPrivate || roleStatus));

            if (!string.IsNullOrEmpty(noteCategory))
                 notes = notes.Where(a => a.NoteType.Description.Contains(noteCategory));;

            if (!string.IsNullOrEmpty(body))
                notes = notes.Where(a => a.Body.Contains(body));




            return View(notes.ToList()); ;
        }*/
        //
        // GET: /Note/Details/5

        public ViewResult Details(int id)
        {
            Note note = db.Notes.Single(n => n.NoteID == id);
            return View(note);
        }

        //
        // GET: /Note/Create

        public ActionResult Create()
        {
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName");
            ViewBag.NoteTypeID = new SelectList(db.NoteTypes, "NoteTypeID", "Description");
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName");
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID");
            return View();
        } 

        //
        // POST: /Note/Create

        [HttpPost]
        public ActionResult Create(Note note)
        {
            if (ModelState.IsValid)
            {
                note.CreatedByUserID = CurrentUser.UserID;
                note.UserID = CurrentUser.UserID;
                note.JobID = CurrentJob.JobID;
                note.ClientID= CurrentJob.ClientID;
               
                db.Notes.AddObject(note);
                db.SaveChanges();
                return RedirectToAction("Index");  
            }

          //  ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.UserID);
            ViewBag.NoteTypeID = new SelectList(db.NoteTypes, "NoteTypeID", "Description", note.NoteTypeID);
           // ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.CreatedByUserID);
           // ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID", note.JobID);
            return View(note);
        }
        
        //
        // GET: /Note/Edit/5
 
        public ActionResult Edit(int id)
        {
            var notes = db.Notes.Include("aspnet_Users").Include("NoteType").Where(s => s.NoteID == id);
            if(notes.Count()== 1) 
            {
              Note note = notes.Single(n => n.NoteID == id);
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.UserID);
            ViewBag.NoteTypeID = new SelectList(db.NoteTypes, "NoteTypeID", "Description", note.NoteTypeID);
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.CreatedByUserID);
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID", note.JobID);
            return View(note);
            }
            else
                return RedirectToAction("Index"); 
        
        }

        //
        // POST: /Note/Edit/5

        [HttpPost]
        public ActionResult Edit(Note note)
        {
            if (ModelState.IsValid)
            {
                note.UserID = CurrentUser.UserID;
                db.Notes.Attach(note);
                db.ObjectStateManager.ChangeObjectState(note, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.UserID);
            ViewBag.NoteTypeID = new SelectList(db.NoteTypes, "NoteTypeID", "Description", note.NoteTypeID);
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.CreatedByUserID);
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID", note.JobID);
            return View(note);
        }
        //
        // GET: /Note/MakePrivate/5

        public ActionResult MakePrivate(int id)
        {
            var notes = db.Notes.Include("aspnet_Users").Include("NoteType").Where(s => s.NoteID == id  );
            if (notes.Count() == 1)
            {
                Note note = notes.Single(n => n.NoteID == id);
                ViewBag.NoteTypeID = new SelectList(db.NoteTypes, "NoteTypeID", "Description", note.NoteTypeID);
                return View(note);
            }
            else
                return RedirectToAction("Index");

        }

        //
        // POST: /Note/MakePrivate/5

        [HttpPost]
        public ActionResult MakePrivate(Note note)
        {
            if (ModelState.IsValid)
            {
                note.UserID = CurrentUser.UserID;
                db.Notes.Attach(note);
                db.ObjectStateManager.ChangeObjectState(note, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.UserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.UserID);
            ViewBag.NoteTypeID = new SelectList(db.NoteTypes, "NoteTypeID", "Description", note.NoteTypeID);
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", note.CreatedByUserID);
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID", note.JobID);
            return View(note);
        }

        //
        // GET: /Note/Delete/5
 
        public ActionResult Delete(int id)
        {
            var notes = db.Notes.Include("aspnet_Users").Include("NoteType").Where(s => s.JobID == CurrentJob.JobID);
            if (notes.Count() == 1)
            {
                Note note = notes.Single(n => n.NoteID == id);

                return View(note);
            }
            else
                return RedirectToAction("Index"); 
        }

        //
        // POST: /Note/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {            
            Note note = db.Notes.Single(n => n.NoteID == id);
            db.Notes.DeleteObject(note);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}