﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using JobTracking.Models;

namespace JobTracking.Controllers
{ 
    public class TicketController : Controller
    {
        private JobTrackerEntities db = new JobTrackerEntities();

        //
        // GET: /Ticket/

        public ViewResult Index()
        {
            var tickets = db.Tickets.Include("aspnet_Users").Include("Client").Include("Job").Where(s => s.JobID == CurrentJob.JobID);;
            return View(tickets.ToList());
        }

        //
        // GET: /Ticket/Details/5

        public ViewResult Details(int id)
        {
            Ticket ticket = db.Tickets.Single(t => t.TicketID == id);
            return View(ticket);
        }

        //
        // GET: /Ticket/Create

        public ActionResult Create()
        {
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName");
            ViewBag.ClentID = new SelectList(db.Clients, "ClientID", "CompanyName");
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID");
            return View();
        } 

        //
        // POST: /Ticket/Create

        [HttpPost]
        public ActionResult Create(Ticket ticket)
        {
            if (ModelState.IsValid)
            {
                ticket.CreationDateTime = DateTime.Now;
                ticket.CreatedByUserID = CurrentUser.UserID;
                ticket.JobID = CurrentJob.JobID;
                ticket.ClentID = CurrentJob.ClientID;

                db.Tickets.AddObject(ticket);
                db.SaveChanges();
                return RedirectToAction("Index");  
            }

            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", ticket.CreatedByUserID);
            ViewBag.ClentID = new SelectList(db.Clients, "ClientID", "CompanyName", ticket.ClentID);
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID", ticket.JobID);
            return View(ticket);
        }
        
        //
        // GET: /Ticket/Edit/5
 
        public ActionResult Edit(int id)
        {
            Ticket ticket = db.Tickets.Include("aspnet_Users").Include("Client").Include("Job").Single(t => t.TicketID == id);
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", ticket.CreatedByUserID);
            ViewBag.ClentID = new SelectList(db.Clients, "ClientID", "CompanyName", ticket.ClentID);
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID", ticket.JobID);
            return View(ticket);
        }

        //
        // POST: /Ticket/Edit/5

        [HttpPost]
        public ActionResult Edit(Ticket ticket)
        {
            if (ModelState.IsValid)
            {
                db.Tickets.Attach(ticket);
                db.ObjectStateManager.ChangeObjectState(ticket, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.CreatedByUserID = new SelectList(db.aspnet_Users, "UserId", "UserName", ticket.CreatedByUserID);
            ViewBag.ClentID = new SelectList(db.Clients, "ClientID", "CompanyName", ticket.ClentID);
            ViewBag.JobID = new SelectList(db.Jobs, "JobID", "JobID", ticket.JobID);
            return View(ticket);
        }

        //
        // GET: /Ticket/Delete/5
 
        public ActionResult Delete(int id)
        {
            Ticket ticket = db.Tickets.Include("aspnet_Users").Include("Client").Include("Job").Single(t => t.TicketID == id);
            return View(ticket);
        }

        //
        // POST: /Ticket/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {            
            Ticket ticket = db.Tickets.Single(t => t.TicketID == id);
            db.Tickets.DeleteObject(ticket);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}